# Changelog

## [0.2.6a1](https://github.com/OpenVoiceOS/ovos-PHAL/tree/0.2.6a1) (2024-10-31)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-PHAL/compare/0.2.5...0.2.6a1)

**Merged pull requests:**

- fix:remove unused dependency [\#53](https://github.com/OpenVoiceOS/ovos-PHAL/pull/53) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
